package WebGUI::i18n::Spanish::Asset_Post;
use utf8;
our $I18N = {
  523 => {
    'lastUpdated' => '1253404305',
    'message' => 'Notificación'
  },
  875 => {
    'lastUpdated' => '1253404326',
    'message' => 'Un nuevo mensaje ha sido publicado a una de sus suscripciones.'
  },
  'By' => {
    'lastUpdated' => '1253404336',
    'message' => 'Por'
  },
  'Edited_on' => {
    'lastUpdated' => '1253404344',
    'message' => 'Editado el'
  },
  'Skip notification' => {
    'lastUpdated' => '1270050629',
    'message' => 'Omitir notificación'
  },
  'add/edit post template title' => {
    'lastUpdated' => '1253404359',
    'message' => 'Plantilla para Agregar/Editar Publicación'
  },
  'approved' => {
    'lastUpdated' => '1253404446',
    'message' => 'Aprobado'
  },
  'archive.form' => {
    'lastUpdated' => '1253404517',
    'message' => 'Un botón "si/no" para archivar el Hilo tan pronto se envíe esta respuesta. Solamente está disponible para los moderadores.'
  },
  'archived' => {
    'lastUpdated' => '1253404567',
    'message' => 'Archivado'
  },
  'assetName' => {
    'lastUpdated' => '1253404583',
    'message' => 'Publicación'
  },
  'assetSize' => {
    'lastUpdated' => '1253404656',
    'message' => 'El tamaño de esta Publicación, una vez aplicado el formato.'
  },
  'attachment.form' => {
    'lastUpdated' => '1253404679',
    'message' => 'Código que permite agregar el adjunto a la Publicación.'
  },
  'attachment.icon' => {
    'lastUpdated' => '1253404725',
    'message' => 'Un ícono que muestra el tipo de archivo de este adjunto.'
  },
  'attachment.name' => {
    'lastUpdated' => '1253405069',
    'message' => 'El nombre del primer adjunto encontrado en la Publicación.'
  },
  'attachment.url' => {
    'lastUpdated' => '1253405090',
    'message' => 'El URL para descargar el primer adjunto de la Publicación.'
  },
  'attachment_loop' => {
    'lastUpdated' => '1253405108',
    'message' => 'Un ciclo que itera sobre todos los archivos e imágenes adjuntas a la Publicación.'
  },
  'avatar.url' => {
    'lastUpdated' => '1253405198',
    'message' => 'El URL al avatar del propietario de la Publicación, si los avatares están habilitados en el Sistema Colaborativo que la contiene y el usuario tiene avatar.'
  },
  'content' => {
    'lastUpdated' => '1253405207',
    'message' => 'El contenido o cuerpo de la Publicación.'
  },
  'content.form' => {
    'lastUpdated' => '1253405304',
    'message' => 'Un campo para ingresar o editar el contenido, pero con todos los macros deshabilitados. Si el foro de discusión permite contenido enriquecido, será un área HTML WYSIWYG; en caso contrario, será un HTML TextArea.'
  },
  'contentType' => {
    'lastUpdated' => '1253405768',
    'message' => 'El tipo de contenido en la Publicación, típicamente "código", "texto", "HTML" o "mixto".'
  },
  'contentType.form' => {
    'lastUpdated' => '1253406048',
    'message' => 'Un campo de formulario que describe cuál es el formato de la Publicación, sea HTML, texto, código o mixto, este último por omisión.'
  },
  'dateSubmitted' => {
    'lastUpdated' => '1253406067',
    'message' => 'La fecha en que la Publicación fue enviada, como una época Unix.'
  },
  'dateSubmitted.human' => {
    'lastUpdated' => '1253406121',
    'message' => 'La fechta en que la Publicación fue enviada, en formato legible.'
  },
  'dateUpdated' => {
    'lastUpdated' => '1253406158',
    'message' => 'La fecha en que la Publicación fue actualizada por última vez, como una época Unix.'
  },
  'dateUpdated.human' => {
    'lastUpdated' => '1253406176',
    'message' => 'La fecha en que la Publicación fue actualizada por última vez, en formato legible.'
  },
  'delete.url' => {
    'lastUpdated' => '1253406191',
    'message' => 'Un URL para eliminar esta Publicación.'
  },
  'edit.url' => {
    'lastUpdated' => '1253406200',
    'message' => 'Un URL para editar esta Publicación.'
  },
  'extraHeadTags' => {
    'lastUpdated' => '1253406232',
    'message' => 'Marcas HTML extras que el usuario indicó sean agregadas al encabezado HTML.'
  },
  'field' => {
    'lastUpdated' => '1253406259',
    'message' => 'El formulario para este campo de metadatos.'
  },
  'filename' => {
    'lastUpdated' => '1253406273',
    'message' => 'El nombre del archivo adjunto.'
  },
  'form.cancel' => {
    'lastUpdated' => '1272376115',
    'message' => 'Un botón para cancelar la Publicación.'
  },
  'form.footer' => {
    'lastUpdated' => '1253406324',
    'message' => 'El código HTML para terminar el formulario.'
  },
  'form.header' => {
    'lastUpdated' => '1253406352',
    'message' => 'El código HTML para iniciar el formulario.'
  },
  'form.preview' => {
    'lastUpdated' => '1253406369',
    'message' => 'Un botón para preparar la vista previa de la Publicación.'
  },
  'form.submit' => {
    'lastUpdated' => '1253406528',
    'message' => 'El botón para enviar la Publicación.'
  },
  'formatted.content' => {
    'lastUpdated' => '1253406613',
    'message' => 'El contenido de la Publicación con formato y filtrado, siempre y cuando exista un Hilo que contenga a la Publicación. Esta variable opacará a cualquier otra variable con el mismo nombre en la lista de variables de Plantilla.'
  },
  'groupIdEdit' => {
    'lastUpdated' => '1253406634',
    'message' => 'El ID del Grupo con privilegios para editar esta Publicación.'
  },
  'groupIdView' => {
    'lastUpdated' => '1253406645',
    'message' => 'El ID del Grupo con privilegios para ver esta Publicación.'
  },
  'hasRated' => {
    'lastUpdated' => '1253406663',
    'message' => 'Un condicional que indica si el usuario actual ha calificado la Publicación o no.'
  },
  'help url.raw' => {
    'lastUpdated' => '1253406817',
    'message' => 'El URL al Activo Publicación sin el #id al final. Es útil para realizar funciones adicionales con la Publicación, como promoverlo.'
  },
  'icon' => {
    'lastUpdated' => '1253406841',
    'message' => 'El ícono que representa el tipo de archivo del adjunto.'
  },
  'image.thumbnail' => {
    'lastUpdated' => '1253406877',
    'message' => 'Una miniatura de la imagen adjunta a la Publicación.'
  },
  'image.url' => {
    'lastUpdated' => '1253406898',
    'message' => 'El URL a la primera imagen adjunta a la Publicación.'
  },
  'isEdit' => {
    'lastUpdated' => '1253406935',
    'message' => 'Un condicional que indica si el usuario está editando una Publicación existente o no.'
  },
  'isHidden' => {
    'lastUpdated' => '1253406954',
    'message' => 'Un condicional que indica si la Publicación debe ser escondida de la navegación o no.'
  },
  'isImage' => {
    'lastUpdated' => '1253406972',
    'message' => 'Un condicional que indica si el adjunto es una imagen o no.'
  },
  'isNewPost' => {
    'lastUpdated' => '1253407155',
    'message' => 'Un condicional que indica si el usuario está agregando una nueva Publicación o no.'
  },
  'isNewThread' => {
    'lastUpdated' => '1253407171',
    'message' => 'Un condicional que indica si el usuario está agregando un nuevo Hilo o no.'
  },
  'isPackage' => {
    'lastUpdated' => '1253407323',
    'message' => 'Un condicional que indica si esta Publicación está disponible como Paquete.'
  },
  'isPrototype' => {
    'lastUpdated' => '1253407356',
    'message' => 'Un condicional que indica si esta Publicación es un Prototipo de Contenido.'
  },
  'isReply' => {
    'lastUpdated' => '1253407401',
    'message' => 'Un condicional que indica si el usuario está respondiendo a una Publicación existente.'
  },
  'isSubscribedToCs' => {
    'lastUpdated' => '1280249175',
    'message' => 'Un condicional que indica si el usuario actual está suscrito al Sistema de Colaboración que contiene este artículo.'
  },
  'isThread' => {
    'lastUpdated' => '1253407428',
    'message' => 'Un condicional que indica si el usuario está editando la Publicación principal de un Hilo o no.'
  },
  'karmaIsEnabled' => {
    'lastUpdated' => '1253407495',
    'message' => 'Un condicional que indica si el karma está habilitado en el sistema WebGUI o no.'
  },
  'karmaScale.form' => {
    'lastUpdated' => '1253407581',
    'message' => 'Un elemento de formulario que permite a los moderadores establecer una escala para un Hilo particular. Solamente está disponible para Hilos.'
  },
  'lock.form' => {
    'lastUpdated' => '1253407611',
    'message' => 'Un botón si/no para bloquear el Hilo, de manera que ninguna Publicación pueda ser agregada o editada.'
  },
  'menuTitle' => {
    'lastUpdated' => '1253407646',
    'message' => 'El Título para Menú de la Publicación.'
  },
  'meta_X_form' => {
    'lastUpdated' => '1253407758',
    'message' => 'El campo de formulario para un campo particular de metadatos, seleccionado por nombre, donde X es el nombre del campo de metadatos en el cual los espacios en blanco han sido cambiados por _.'
  },
  'meta_X_value' => {
    'lastUpdated' => '1253407773',
    'message' => 'El valor para un campo particular de metadatos,
seleccionado por nombre, donde X es el nombre del campo de metadatos en
el cual los espacios en blanco han sido cambiados por _.'
  },
  'meta_loop' => {
    'lastUpdated' => '1253407829',
    'message' => 'Un ciclo que itera sobre las etiquetas y campos de metadatos de la Publicación. Si los metadatos no están habilitados en el sitio, o no están habilitados en el Sistema de Colaboración, el ciclo estará vacío.'
  },
  'name' => {
    'lastUpdated' => '1253407851',
    'message' => 'La etiqueta para este campo de metadatos.'
  },
  'new file description' => {
    'lastUpdated' => '1253407894',
    'message' => 'Ingrese el camino completo o utilice el botón para explorar el sistema de archivos de su disco duro hasta el archivo que desea agregar.'
  },
  'newWindow' => {
    'lastUpdated' => '1253407922',
    'message' => 'Un condicional que indica si esta Publicación debe ser desplegada en una ventana nueva o no.'
  },
  'notification template body' => {
    'lastUpdated' => '1253407974',
    'message' => 'Además de las Variables de Plantilla para Publicación, la Plantilla de Notificación tiene las siguientes variables:'
  },
  'notification template title' => {
    'lastUpdated' => '1253407998',
    'message' => 'Plantilla para Notificaciones'
  },
  'notify url' => {
    'lastUpdated' => '1253408034',
    'message' => 'El URL a la Publicación que produjo la Notificación.'
  },
  'notify.subscription.message' => {
    'lastUpdated' => '1253408086',
    'message' => 'Mensaje para indicar que un nuevo mensaje ha sido publicado en un Hilo al cual el usuario se ha suscrito.'
  },
  'ownerUserId' => {
    'lastUpdated' => '1253408101',
    'message' => 'Un alias para <strong>userId</strong>.'
  },
  'pending' => {
    'lastUpdated' => '1253408110',
    'message' => 'Pendiente'
  },
  'post asset variables title' => {
    'lastUpdated' => '1253408121',
    'message' => 'Variables de Plantilla para Publicaciones'
  },
  'post received' => {
    'lastUpdated' => '1253408148',
    'message' => 'Su publicación ha sido recibida y está siendo procesada para ser agregada al sitio. Sea paciente.'
  },
  'post template variables title' => {
    'lastUpdated' => '1253408165',
    'message' => 'Variables de Plantilla para Publicaciones'
  },
  'preview.content' => {
    'lastUpdated' => '1253408194',
    'message' => 'El contenido cuando se solicita la vista previa de la Publicación.'
  },
  'preview.synopsis' => {
    'lastUpdated' => '1253408264',
    'message' => 'El resumen sumario cuando se presenta la vista previa de la Publicación. Si no se definió reusmen sumario, se intentará tomar texto de la descripción hasta alcanzar la marca ¯;. Si no se encuentra esa marca, se tomará todo el texto hasta el primer salto de línea de la descripción.'
  },
  'preview.title' => {
    'lastUpdated' => '1253408311',
    'message' => 'El título para la vista previa de la Publicación.'
  },
  'preview.userDefinedN' => {
    'lastUpdated' => '1253408364',
    'message' => 'Los contenidos de los campos definidos por el usuario para la Publicación, sin procesar los Macros WebGUI. Puede usarse N variando entre 1 y 5 inclusive.'
  },
  'rate.url.thumbsDown' => {
    'lastUpdated' => '1253408405',
    'message' => 'Calificación negativa.'
  },
  'rate.url.thumbsUp' => {
    'lastUpdated' => '1253408415',
    'message' => 'Calificación positiva.'
  },
  'rating' => {
    'lastUpdated' => '1253408429',
    'message' => 'Otro nombre para <strong>rating.value</strong>'
  },
  'rating.value' => {
    'lastUpdated' => '1253408447',
    'message' => 'La calificación actual de la Publicación.'
  },
  'relativeUrl' => {
    'lastUpdated' => '1253408539',
    'message' => 'Provee el URL de la Publicación relativo al servidor (/camino/al/articulo) en lugar del nombre completo (http://servidor/camino/al/articulo).'
  },
  'reply.content' => {
    'lastUpdated' => '1253408563',
    'message' => 'EL contenido de la Publicación a la cual se está contestando.'
  },
  'reply.synopsis' => {
    'lastUpdated' => '1253408654',
    'message' => 'El resumen sumario de la Publicación a la cual se está contestando. Si no se definió resumen sumario, entonces se tomará texto de la descripción hasta encontrar la marca ^-;. Si no se encuentra la marca, se tomará texto de la descripción hasta el primer salto de línea.'
  },
  'reply.title' => {
    'lastUpdated' => '1253408694',
    'message' => 'El título de la Publicación a la cual se está contestando.'
  },
  'reply.url' => {
    'lastUpdated' => '1253408758',
    'message' => 'El URL para contestar a esta Publicación sin citarla.'
  },
  'reply.userDefinedN' => {
    'lastUpdated' => '1253408790',
    'message' => 'Los contenidos de los campos definidos por el usuario para la Publicación a la cual se está contestando. Se puede variar N entre 1 y 5.'
  },
  'reply.withQuote.url' => {
    'lastUpdated' => '1253408833',
    'message' => 'El URL para citar y contestar a esta Publicación.'
  },
  'skipNotification.form' => {
    'lastUpdated' => '1270050657',
    'message' => 'El campo que permite al usuario con privilegios adecuados omitir las notificaciones por correo electrónico.'
  },
  'status' => {
    'lastUpdated' => '1253408849',
    'message' => 'El estado de esta Publicación: "Aprobado", "Pendiente" o "Archivado".'
  },
  'sticky.form' => {
    'lastUpdated' => '1253408881',
    'message' => 'Un botón si/no para establecer que la Publicación sea pegajosa, de manera que siempre aparezca al comienzo del listado en el foro.'
  },
  'storageId' => {
    'lastUpdated' => '1253408940',
    'message' => 'El Asset ID del nodo de almacenamiento de esta Publicación en el cual estan los adjuntos.'
  },
  'subscribe.form' => {
    'lastUpdated' => '1253408967',
    'message' => 'Un botón si/no que permite al usuario suscribirse al Hilo al cual pertenece esta Publicación.'
  },
  'synopsis' => {
    'lastUpdated' => '1253409012',
    'message' => 'El resumen sumario de la Publicación. Si no se ha definido resumen sumario, se tomará texto de la descripción hasta encontrar la marca ^-;. Si la marca no se encuentra, se tomará texto de la descripción hasta el primer salto de línea.'
  },
  'synopsis.form' => {
    'lastUpdated' => '1253409030',
    'message' => 'Un campo de formulario para agregar o editar el resumen sumario.'
  },
  'threadId' => {
    'lastUpdated' => '1253409055',
    'message' => 'El ID del Hilo que contiene esta Publicación.'
  },
  'thumbnail' => {
    'lastUpdated' => '1253409117',
    'message' => 'Una miniatura del adjunto, si aplica.'
  },
  'title' => {
    'lastUpdated' => '1253409132',
    'message' => 'El Título de la Publicación.'
  },
  'title.form' => {
    'lastUpdated' => '1253409163',
    'message' => 'Un campo de formulario de una línea para ingresar o editar el Título, sin HTML y con macros deshabilitados.'
  },
  'title.form.textarea' => {
    'lastUpdated' => '1253409189',
    'message' => 'Un campo HTML TextArea para ingresar o editar el Título, sin HTML y con macros deshabilitados.'
  },
  'title.short' => {
    'lastUpdated' => '1253409202',
    'message' => 'El Título de la Publicación, limitado a 30 caracteres.'
  },
  'unsubscribeLinkText' => {
    'lastUpdated' => '1253409219',
    'message' => 'Desuscribirme'
  },
  'unsubscribeUrl' => {
    'lastUpdated' => '1253409234',
    'message' => 'El URL para que el usuario se desuscriba.'
  },
  'url' => {
    'lastUpdated' => '1253409246',
    'message' => 'El URL para descargar el adjunto.'
  },
  'usePreview' => {
    'lastUpdated' => '1253409299',
    'message' => 'Un condicional que indica si las Publicaciones en este Hilo deben ser examinadas en vista previa antes de ser enviadas.'
  },
  'user.canEdit' => {
    'lastUpdated' => '1253409321',
    'message' => 'Un condicional que indica si el usuario está agregando una Publicación.'
  },
  'user.isModerator' => {
    'lastUpdated' => '1253409332',
    'message' => 'Un condicional que indica si el usuario es moderador o no.'
  },
  'user.isPoster' => {
    'lastUpdated' => '1253409347',
    'message' => 'Un condicional que indica si el usuario es el propietario de la Publicación.'
  },
  'user.isVisitor' => {
    'lastUpdated' => '1253409359',
    'message' => 'Un condicional que indica si el usuario es visitante o no.'
  },
  'userDefined1' => {
    'lastUpdated' => '1253409380',
    'message' => 'El valor contenido en la primera variable definida por el usuario.'
  },
  'userDefined2' => {
    'lastUpdated' => '1253409387',
    'message' => 'El valor contenido en la segunda variable definida por el usuario.'
  },
  'userDefined3' => {
    'lastUpdated' => '1253409394',
    'message' => 'El valor contenido en la tercera variable definida por el usuario.'
  },
  'userDefined4' => {
    'lastUpdated' => '1253409400',
    'message' => 'El valor contenido en la cuarta variable definida por el usuario.'
  },
  'userDefined5' => {
    'lastUpdated' => '1253409405',
    'message' => 'El valor contenido en la quinta variable definida por el usuario.'
  },
  'userDefinedN.form' => {
    'lastUpdated' => '1253409431',
    'message' => 'Para cada uno de los cinco campos definidos por el usuario, un campo de formulario para una línea de texto.'
  },
  'userDefinedN.form.float' => {
    'lastUpdated' => '1253409454',
    'message' => 'Para cada uno de los cinco campos definidos por el usuario, un campo de formulario para un número con decimales.'
  },
  'userDefinedN.form.htmlarea' => {
    'lastUpdated' => '1253409477',
    'message' => 'Para cada uno de los cinco campos definidos por el usuario, un campo de formulario para un HTML Area WYSIWYG.'
  },
  'userDefinedN.form.textarea' => {
    'lastUpdated' => '1253409502',
    'message' => 'Para cada uno de los cinco campos definidos por el usuario, un campo de formulario para un HTML Text Area.'
  },
  'userDefinedN.form.yesNo' => {
    'lastUpdated' => '1253409527',
    'message' => 'Para cada uno de los cinco campos definidos por el usuario, un campo de formulario con un botón si/no.'
  },
  'userId' => {
    'lastUpdated' => '1253409546',
    'message' => 'El <strong>UserID</strong> del propietario de la Publicación.'
  },
  'userProfile.url' => {
    'lastUpdated' => '1253409564',
    'message' => 'El URL al perfil del usuario propietario de esta Publicación.'
  },
  'username' => {
    'lastUpdated' => '1253409578',
    'message' => 'El nombre del usuario que actualizó por última vez la Publicación.'
  },
  'value' => {
    'lastUpdated' => '1253409594',
    'message' => 'El valor de este campo de metadatos para esta Publicación'
  },
  'views' => {
    'lastUpdated' => '1253409612',
    'message' => 'El número de veces que ha sido vista la Publicación'
  },
  'visitorName.form' => {
    'lastUpdated' => '1253409620',
    'message' => 'Una forma en la que el usuario puede introducir su nombre, incluso cuando se trate de un visitante.'
  }
}
;

1;
